cmoncrawl.processor.pipeline.router.Router — CmonCrawl 1.0.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# cmoncrawl.processor.pipeline.router.Router

class cmoncrawl.processor.pipeline.router.Router
  __init__()

  Methods

  `__init__`() |
  `load_extractor`(name, extractor) |
  `load_module`(module_path) |
  `load_module_as_extractor`(module_path) |
  `load_modules`(folder) |
  `register_route`(name, regex[, since, to]) |
  `register_routes`(config) |
  `route`(url, time, metadata) |